@@ -1,7 +1,7 @@
 import unittest
 
 from lance.generators.java.helper import class_name_from_package
-from lance.generators.java.typs import process_type, TYPE_STRING, TYPE_LIST_STRING
+from lance.generators.java.typs import process_type, TYPE_STRING
 
 
 class MyTestCase(unittest.TestCase):
@@ -13,10 +13,6 @@ class MyTestCase(unittest.TestCase):
         v = process_type(TYPE_STRING)
         print(v)
 
-    def test_list_object(self):
-        v = process_type(TYPE_LIST_STRING)
-        print(v)
-
 
 
 if __name__ == '__main__':
